@@ -55,7 +55,7 @@ class AnalysisForm(forms.Form):
                         ('C','Neighbourhood based on CELEX'))
     else:
         NEIGH_DEN_CHOICES = (('N','None'),
-                            ('VB','Vitevitch & Luce from Buckeye corpus words'))
+                            ('B','Neighbourhood based on Buckeye words'))
     measure = forms.CharField(label='Measure')
     DispersionFromAH = forms.BooleanField(initial=False,required=False,label="Dispersion from a speaker's AH tokens")
     measure.widget = forms.Select(choices=M_CHOICES)
@@ -80,7 +80,8 @@ class AnalysisForm(forms.Form):
     orthoLength = forms.BooleanField(initial=True,required=False,label='Orthographic length')
     phonoLength = forms.BooleanField(initial=True,required=False,label='Phonological length')
     numSylls = forms.BooleanField(initial=True,required=False,label='Number of syllables')
-    semPred = forms.BooleanField(initial=True,required=False,label='Semantic predictability')
+    prev_sem_pred = forms.BooleanField(initial=True,required=False,label='Previous semantic predictability')
+    foll_sem_pred = forms.BooleanField(initial=True,required=False,label='Following semantic predictability')
 
     class Meta:
         fieldsets = ((None,
